==> minitube-0.9.tar.gz: minitube/locale/nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nb_NO" sourcelanguage="en">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Det finnes et liv utenfor nettleseren!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versjon %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>Dette er en betarelease, ikke forvent at den er perfekt.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Rapporter bugs og send inn dine ideer til %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 er Fri Programvare men utviklingen tar verdifull tid.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;doner via PayPal&lt;/a&gt; for å gjøre fortsatt utvikling av %2 mulig.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikon er designet av %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Kompakt-Visning er utviklet av %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>HTTP proxy support utviklet av %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Windows versjon bygget av %1</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Oversatt av %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Sluppet under &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Steng</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Hva du alltid har villet visst om %1 men aldri torde å spørre</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Nullstill</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Søker...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Vis %1 flere</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Ingen videoer</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Ingen flere videoer</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Tilbake</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Gå tilbake til forrige visning</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stopp</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Stopp spilleren og gå tilbake til dine søk</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Hopp over</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Hopp over neste video</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Sett spilleren på pause</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Fullskjerm</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Fullskjermsvisning</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>&amp;Kompakt-Visning</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Gjem spillelista og verktøylinja</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation>&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Åpne filmen på youtube</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Fjern valgte videoer fra spillelista</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Flytt &amp;opp</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Flytt opp valgte videoer i spillelista</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Flytt &amp;Ned</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Flytt ned valgte videoer i spillelista</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Ha en fin dag</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Nettsted</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 på internett</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>&amp;Doner via PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Bidra til fortsatt utvikling av %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informasjon om %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Mute</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Spilleliste</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Trykk på %1 for å stille opp volum, %2 for å skru ned</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Åpner %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Kritisk feil: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Feil: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Spill av</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Gjenoppta avspilling</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Avslutt &amp;Fullskjerm</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Gjenstående tid: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volum %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Mute er på</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Mute er av</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation>High Definition video er aktivert</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation>High Definition video er ikke aktivert</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation>Denne videoen er i High Definition</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation>Denne videoen er ikke i High Definition</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>&amp;Nullstill siste søkeord</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>Applikasjon</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Mest relevant</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Nyeste</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Mest sett</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Du ser på &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Feil på nettverk: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 visninger</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Velommen til &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Skriv inn et søkeord for å se på videoer.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Se Film</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Aktuelle søkeord</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>En ny versjon av %1 er tilgjengelig. Vennligst &lt;a href=&apos;%2&apos;&gt;oppdater til versjon %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Finn deg til rette</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Innstillinger</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Feil på nettverk: %1 for %2</translation>
    </message>
</context>
</TS>

==> minitube-1.0.tar.gz: minitube/locale/nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nb_NO" sourcelanguage="en">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Det finnes et liv utenfor nettleseren!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versjon %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation type="obsolete">Dette er en betarelease, ikke forvent at den er perfekt.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Rapporter bugs og send inn dine ideer til %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 er Fri Programvare men utviklingen tar verdifull tid.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation type="obsolete">&lt;a href=&apos;%1&apos;&gt;doner via PayPal&lt;/a&gt; for å gjøre fortsatt utvikling av %2 mulig.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikon er designet av %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Kompakt-Visning er utviklet av %1.</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>HTTP proxy support utviklet av %1.</translation>
    </message>
    <message>
        <source>Windows version built by %1</source>
        <translation type="obsolete">Windows versjon bygget av %1</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Oversatt av %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Sluppet under &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Steng</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Hva du alltid har villet visst om %1 men aldri torde å spørre om</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Vennligst &lt;a href=&apos;%1&apos;&gt;doner&lt;/a&gt; for og støtte vidre utvikling av %2.</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Nullstill</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Søker...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Vis %1 flere</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Ingen videoer</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Ingen flere videoer</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation type="obsolete">&amp;Tilbake</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation type="obsolete">Gå tilbake til forrige visning</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stopp</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Stopp avspilling og gå tilbake til dine søk</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Hopp over</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Hopp over neste video</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Sett avspilling på pause</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Fullskjerm</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Fullskjermsvisning</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>&amp;Kompakt-Visning</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Gjem spillelista og verktøylinja</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation type="obsolete">&amp;YouTube</translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation type="obsolete">Åpne filmen på youtube</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Fjern valgte videoer fra spillelista</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Flytt &amp;opp</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Flytt opp valgte videoer i spillelista</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Flytt &amp;Ned</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Flytt ned valgte videoer i spillelista</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Ha en fin dag</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Nettsted</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 på internett</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation type="obsolete">&amp;Doner via PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Bidra til fortsatt utvikling av %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informasjon om %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Mute</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Spilleliste</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Trykk på %1 for å stille opp volum, %2 for å skru ned</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Åpner %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Kritisk feil: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Feil: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Spill av</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Gjenoppta avspilling</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Avslutt &amp;Fullskjerm</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Gjenstående tid: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volum %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Mute er på</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Mute er av</translation>
    </message>
    <message>
        <source>High Definition video is enabled</source>
        <translation type="obsolete">High Definition video er aktivert</translation>
    </message>
    <message>
        <source>High Definition video is not enabled</source>
        <translation type="obsolete">High Definition video er ikke aktivert</translation>
    </message>
    <message>
        <source>The current video is in High Definition</source>
        <translation type="obsolete">Denne videoen er i High Definition</translation>
    </message>
    <message>
        <source>The current video is not in High Definition</source>
        <translation type="obsolete">Denne videoen er ikke i High Definition</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>&amp;Nullstill siste søkeord</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>Applikasjon</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Klarer søkehistorie. Kan ikke bli angert.</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Ditt privatliv er nå sikkert</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>Åpne &amp;YouTube side</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Gå til YouTube video siden og pause avspillingen</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>Kopier YouTube &amp;link</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopier denne YouTube video linken til utklippstavle</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>Kopier video stream &amp;URL</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopier denne video stream URL til utklippstavle</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Gjør en &amp;donasjon</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Maksimum video definisjon innstilling til %1</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Mest relevant</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Nyeste</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Mest sett</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Du ser på &quot;%1&quot;</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Du kan nå lime inn YouTube linken i et annet program</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Du kan nå lime inn video stream URL i et annet applikasjon</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Denne linken vil kun være gyldig i en begrenset tid.</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Feil på nettverk: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 visninger</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Velommen til &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Skriv inn et søkeord for å se på videoer.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Se Film</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Aktuelle søkeord</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>En ny versjon av %1 er tilgjengelig. Vennligst &lt;a href=&apos;%2&apos;&gt;oppdater til versjon %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Finn deg til rette</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation type="obsolete">Innstillinger</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Feil på nettverk: %1 for %2</translation>
    </message>
</context>
</TS>
